summaryrefslogtreecommitdiff
path: root/sbin/newfs/newfs.c
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>2007-05-19 01:28:16 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>2007-05-19 01:28:16 +0000
commit7d6ed300566328aa308dc9e8f6021fad4d97272c (patch)
treeb0cd904ca1d77f376d806e8466b99a26775e339a /sbin/newfs/newfs.c
parent40c1dbd030c08abbb2865ac6ff43b7691d5a980f (diff)
backout -c changes; they were not tested on all the media. all newfs
changes obviously *MUST* be checked against whatever weird things the floppies do to fit
Diffstat (limited to 'sbin/newfs/newfs.c')
-rw-r--r--sbin/newfs/newfs.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/sbin/newfs/newfs.c b/sbin/newfs/newfs.c
index 7d6a24c9c76..91c6827c774 100644
--- a/sbin/newfs/newfs.c
+++ b/sbin/newfs/newfs.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: newfs.c,v 1.61 2007/05/18 19:08:16 otto Exp $ */
+/* $OpenBSD: newfs.c,v 1.62 2007/05/19 01:28:15 deraadt Exp $ */
/* $NetBSD: newfs.c,v 1.20 1996/05/16 07:13:03 thorpej Exp $ */
/*
@@ -116,7 +116,7 @@ int sectorsize; /* bytes/sector */
int realsectorsize; /* bytes/sector in hardware */
int fsize = 0; /* fragment size */
int bsize = 0; /* block size */
-int maxfrgspercg = INT_MAX; /* maximum fragments per cylinder group */
+int maxblkspercg = INT_MAX; /* maximum blocks per cylinder group */
int minfree = MINFREE; /* free space threshold */
int opt = DEFAULTOPT; /* optimization preference (space or time) */
int reqopt = -1; /* opt preference has not been specified */
@@ -205,9 +205,9 @@ main(int argc, char *argv[])
fatal("block size is %s: %s", errstr, optarg);
break;
case 'c':
- maxfrgspercg = strtonum(optarg, 1, INT_MAX, &errstr);
+ maxblkspercg = strtonum(optarg, 1, INT_MAX, &errstr);
if (errstr)
- fatal("fragments per cylinder group is %s: %s",
+ fatal("blocks per cylinder group is %s: %s",
errstr, optarg);
break;
case 'e':
@@ -668,7 +668,7 @@ usage(void)
} else {
fprintf(stderr,
"usage: %s [-Nq] [-b block-size] "
- "[-c fragments-per-cylinder-group] [-e maxbpg]\n"
+ "[-c blocks-per-cylinder-group] [-e maxbpg]\n"
"\t[-f frag-size] [-g avgfilesize] [-h avgfpdir] [-i bytes]\n"
"\t[-m free-space] [-O filesystem-format] [-o optimization]\n"
"\t[-S sector-size] [-s size] [-t fstype] special\n",